@@ -1,10 +1,7 @@
-import subprocess
 import os
 import sys
-import re
-import threading
 import logging
-
+from dockerup.proc import read_command
 
 class Docker(object):
 
@@ -61,7 +58,7 @@ class Docker(object):
 	def pull(self, image):
 
 		self.log.debug('Pulling image: %s', image)
-		for line in self.__read_command(['docker', 'pull', image]):
+		for line in read_command(['docker', 'pull', image]):
 			if line.startswith('Status: Downloaded newer image'):
 				return True
 
@@ -79,7 +76,7 @@ class Docker(object):
 
 		self.log.debug('Running container: %s' % image)
 
-		container = self.__read_command(args).strip()
+		container = read_command(args).strip()
 
 		self.log.info('Started container: %s' % container)
 
@@ -88,13 +85,13 @@ class Docker(object):
 	# Start existing container
 	def start(self, container):
 		self.log.debug('Starting container: %s', container)
-		out = self.__read_command(['docker', 'start', container])
+		out = read_command(['docker', 'start', container])
 
 	# Stop running container
 	def stop(self, container, remove=True):
 
 		self.log.debug('Stopping container: %s', container)
-		out = self.__read_command(['docker', 'stop', container])
+		out = read_command(['docker', 'stop', container])
 
 		if remove:
 			self.rm(container)
@@ -103,13 +100,13 @@ class Docker(object):
 	def rm(self, container):
 
 		self.log.debug('Removing stopped container: %s' % container)
-		out = self.__read_command(['docker', 'rm', container])
+		out = read_command(['docker', 'rm', container])
 
 	# Remove image
 	def rmi(self, image):
 
 		self.log.debug('Removing image: %s' % image)
-		out = self.__read_command(['docker', 'rmi', image])
+		out = read_command(['docker', 'rmi', image])
 
 	# Cleanup stopped containers and unused images
 	def cleanup(self, images=True):
@@ -136,7 +133,7 @@ class Docker(object):
 
 	def __load_images(self):
 
-		out = self.__read_command(['docker', 'images', '--no-trunc'], True, '<none>')
+		out = read_command(['docker', 'images', '--no-trunc'], True, '<none>')
 
 		images = []
 
@@ -148,7 +145,7 @@ class Docker(object):
 
 	def __load_containers(self):
 
-		out = self.__read_command(['docker', 'ps', '-a', '--no-trunc'], True)
+		out = read_command(['docker', 'ps', '-a', '--no-trunc'], True)
 
 		containers = []
 		images = self.images()
@@ -169,49 +166,3 @@ class Docker(object):
 			})
 		
 		return containers
-
-	def __read_command(self, command, as_dict=False, nul_value=None, timeout=0):
-
-		proc = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-		
-		if timeout > 0:
-			threading.Timer(timeout, self.__kill_process, (proc,)).start()
-
-		contents = proc.stdout.read()
-
-		if proc.wait() != 0:
-			self.log.debug('Command failed: %s\nSTDOUT:\n%s\nSTDERR:\n%s' % (' '.join(command), contents.strip(), proc.stderr.read().strip()))
-			raise Exception('Command failed: %s' % ' '.join(command))
-
-		if as_dict:
-
-			lines = re.split('\s*\n', contents)
-			labels = self.__split_fields(lines[0])
-
-			rows = []
-
-			for line in lines[1:]:
-				if line:
-					rows.append(dict(zip(labels, self.__split_fields(line, nul_value))))
-
-			return rows
-
-		return contents
-
-	def __kill_process(self, proc):
-
-		if proc.poll() is None:
-			self.log.error( 'Error: process taking too long to complete - terminating')
-			proc.kill()
-
-	def __split_fields(self, line, nul_value=None):
-
-		fields = re.split('\s\s+', line)
-
-		if nul_value:
-			for i in range(0, len(fields)):
-				if fields[i] == nul_value:
-					fields[i] = None
-
-		return fields
-
